@@ -1,6 +1,6 @@
-package HTTP::Throwable::Role::Status::BadRequest;
+package HTTP::Throwable::Role::Status::BadRequest 0.028;
 our $AUTHORITY = 'cpan:STEVAN';
-$HTTP::Throwable::Role::Status::BadRequest::VERSION = '0.026';
+
 use Moo::Role;
 
 with(
@@ -24,7 +24,7 @@ HTTP::Throwable::Role::Status::BadRequest - 400 Bad Request
 
 =head1 VERSION
 
-version 0.026
+version 0.028
 
 =head1 DESCRIPTION
 
@@ -32,6 +32,16 @@ The request could not be understood by the server due to
 malformed syntax. The client SHOULD NOT repeat the request
 without modifications.
 
+=head1 PERL VERSION
+
+This library should run on perls released even a long time ago.  It should work
+on any version of perl released in the last five years.
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 AUTHORS
 
 =over 4
@@ -42,13 +52,13 @@ Stevan Little <stevan.little@iinteractive.com>
 
 =item *
 
-Ricardo Signes <rjbs@cpan.org>
+Ricardo Signes <cpan@semiotic.systems>
 
 =back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Infinity Interactive, Inc..
+This software is copyright (c) 2011 by Infinity Interactive, Inc.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
